@@ -38,8 +38,6 @@ public:
 class CLocalSearchFileData final : public CLocalRecursiveOperation::listing::entry
 {
 public:
-	bool is_dir() const { return dir; }
-	bool dir{};
 	CLocalPath path;
 };
 
@@ -199,7 +197,7 @@ void CSearchDialogFileList::set_mode(CSearchDialog::search_mode mode)
 bool CSearchDialogFileList::ItemIsDir(int index) const
 {
 	if (mode_ == CSearchDialog::search_mode::local) {
-		return localFileData_[index].dir;
+		return localFileData_[index].is_dir();
 	}
 	else {
 		return remoteFileData_[index].is_dir();
@@ -416,13 +414,14 @@ int CSearchDialogFileList::OnGetItemImage(long item) const
 			return -1;
 		}
 		auto const& file = localFileData_[index];
-		icon = pThis->GetIconIndex(iconType::file, file.path.GetPath() + file.name, true);
+		icon = pThis->GetIconIndex(iconType::file, file.path.GetPath() + file.name, true, file.is_link());
 	}
 	else {
 		if (index >= remoteFileData_.size()) {
 			return -1;
 		}
-		icon = pThis->GetIconIndex(iconType::file, remoteFileData_[index].name, false);
+		auto const& file = remoteFileData_[index];
+		icon = pThis->GetIconIndex(iconType::file, file.name, false, file.is_link());
 	}
 
 	return icon;
@@ -472,7 +471,7 @@ void CSearchDialogFileList::StartComparison()
 
 		if (mode_ == CSearchDialog::search_mode::local) {
 			CLocalSearchFileData localData;
-			localData.dir = false;
+			localData.flags = 0;
 			localData.size = -1;
 			localFileData_.push_back(localData);
 		}
@@ -917,10 +916,21 @@ void CSearchDialog::ProcessDirectoryListing(std::shared_ptr<CDirectoryListing> c
 		CRemoteSearchFileData remoteData;
 		static_cast<CDirentry&>(remoteData) = entry;
 		remoteData.path = listing->path;
-		results->remoteFileData_.emplace_back(std::move(remoteData));
 
 		CGenericFileData data;
-		data.icon = entry.is_dir() ? m_results->m_dirIcon : -2;
+		if (entry.is_dir()) {
+			data.icon = m_results->m_dirIcon;
+#ifndef __WXMSW__
+			if (entry.is_link()) {
+				data.icon += 3;
+			}
+#endif
+		}
+		else {
+			data.icon = -2;
+		}
+
+		results->remoteFileData_.emplace_back(std::move(remoteData));
 		results->m_fileData.emplace_back(std::move(data));
 
 		auto insertPos = std::lower_bound(results->m_indexMapping.begin(), results->m_indexMapping.end(), old_count + added_count, SortPredicate(compare));
@@ -981,11 +991,21 @@ void CSearchDialog::ProcessDirectoryListing(CLocalRecursiveOperation::listing co
 		CLocalSearchFileData localData;
 		static_cast<CLocalRecursiveOperation::listing::entry&>(localData) = entry;
 		localData.path = listing.localPath;
-		localData.dir = dir;
-		m_results->localFileData_.emplace_back(std::move(localData));
 
 		CGenericFileData data;
-		data.icon = dir ? m_results->m_dirIcon : -2;
+		if (dir) {
+			data.icon = m_results->m_dirIcon;
+#ifndef FZ_WINDOWS
+			if (localData.is_link()) {
+				data.icon += 3;
+			}
+#endif
+		}
+		else {
+			data.icon = -2;
+		}
+
+		m_results->localFileData_.emplace_back(std::move(localData));
 		m_results->m_fileData.emplace_back(std::move(data));
 
 		auto insertPos = std::lower_bound(m_results->m_indexMapping.begin(), m_results->m_indexMapping.end(), old_count + added_count, SortPredicate(compare));
@@ -1793,19 +1813,19 @@ void CSearchDialog::OnCharHook(wxKeyEvent& event)
 #ifdef __WXMSW__
 int CSearchDialogFileList::GetOverlayIndex(int item)
 {
-	if (mode_ == CSearchDialog::search_mode::local) {
-		return 0;
-	}
 	if (item < 0 || item >= (int)m_indexMapping.size()) {
 		return 0;
 	}
 	int index = m_indexMapping[item];
 
-	if (remoteFileData_[index].is_link()) {
-		return GetLinkOverlayIndex();
+	if (mode_ == CSearchDialog::search_mode::local) {
+		auto const& file = localFileData_[index];
+		return file.is_link() ? GetLinkOverlayIndex() : 0;
+	}
+	else {
+		auto const& file = remoteFileData_[index];
+		return file.is_link() ? GetLinkOverlayIndex() : 0;
 	}
-
-	return 0;
 }
 #endif
 
@@ -2100,7 +2120,7 @@ void CSearchDialog::OnShowFileManager(wxCommandEvent& event)
 	for (auto const& data : selected_item_list) {
 
 		std::wstring const fn = data.path.GetPath() + data.name;
-		if (data.dir) {
+		if (data.is_dir()) {
 			OpenInFileManager(fn);
 			continue;
 		}
